.. _combinatiorics-docs:

=============
Combinatorics
=============

.. toctree::
   :caption: Contents
   :name: combtoc
   :maxdepth: 2

   partitions
   permutations
   perm_groups
   polyhedron
   prufer
   subsets
   graycode
   named_groups
   util
   group_constructs
   testutil
   tensor_can
